@@ -1037,7 +1037,7 @@ public class BezierCurve extends LaTeXDrawPolygon implements Arrowable
 				add+=",shadowangle="+(float)Math.toDegrees(shadowAngle);//$NON-NLS-1$
 			
 			if(((float)shadowSize)!=((float)DEFAULT_SHADOW_SIZE))
-				add+=",shadowsize="+(float)(shadowSize/PPC);//$NON-NLS-1$
+				add+=",shadowsize="+LaTeXDrawNumber.getCutNumber((float)(shadowSize/PPC), threshold);//$NON-NLS-1$
 			
 			if(!shadowColor.equals(PSTricksConstants.DEFAULT_SHADOW_COLOR))
 			{
@@ -1129,16 +1129,16 @@ public class BezierCurve extends LaTeXDrawPolygon implements Arrowable
 		
 		if(lineStyle.equals(PSTricksConstants.LINE_DOTTED_STYLE))
 			add += ",linestyle="+lineStyle+",dotsep="+ //$NON-NLS-1$ //$NON-NLS-2$
-			(dotSep/ppc)+ "cm";	//$NON-NLS-1$
+			LaTeXDrawNumber.getCutNumber(dotSep/ppc, threshold)+ "cm";	//$NON-NLS-1$
 		else
 		if(lineStyle.equals(PSTricksConstants.LINE_DASHED_STYLE))
 			add += ",linestyle="+lineStyle+",dash=" + //$NON-NLS-1$ //$NON-NLS-2$
-			(blackDashLength/ppc) + "cm "+ //$NON-NLS-1$
-			(whiteDashLength/ppc) + "cm";//$NON-NLS-1$
+			LaTeXDrawNumber.getCutNumber(blackDashLength/ppc, threshold) + "cm "+ //$NON-NLS-1$
+			LaTeXDrawNumber.getCutNumber(whiteDashLength/ppc, threshold) + "cm";//$NON-NLS-1$
 
 		if(hasDoubleBoundary)
 		{
-			add+=",doubleline=true,doublesep="+(float)(doubleSep/ppc); //$NON-NLS-1$
+			add+=",doubleline=true,doublesep="+LaTeXDrawNumber.getCutNumber((float)(doubleSep/ppc), threshold); //$NON-NLS-1$
 			
 			if(doubleColor!=PSTricksConstants.DEFAULT_DOUBLE_COLOR)
 			{
@@ -1210,7 +1210,7 @@ public class BezierCurve extends LaTeXDrawPolygon implements Arrowable
 				LaTeXDrawPoint2D tmp = pts.lastElement();
 				pt = pts.firstElement();
 				
-				start = "\\psline[linewidth=" + (thickness/ppc)+add+"](" +//$NON-NLS-1$//$NON-NLS-2$
+				start = "\\psline[linewidth=" + LaTeXDrawNumber.getCutNumber(thickness/ppc, threshold)+add+"](" +//$NON-NLS-1$//$NON-NLS-2$
 						LaTeXDrawNumber.getCutNumber((float)((tmp.x-d.x)/ppc), threshold)+","+ //$NON-NLS-1$
 						LaTeXDrawNumber.getCutNumber((float)((d.y-tmp.y)/ppc), threshold)+")("+ //$NON-NLS-1$
 						LaTeXDrawNumber.getCutNumber((float)((pt.x-d.x)/ppc), threshold)+","+ //$NON-NLS-1$
@@ -1229,7 +1229,7 @@ public class BezierCurve extends LaTeXDrawPolygon implements Arrowable
 			add += ",fillcolor="+name; //$NON-NLS-1$
 		}
 		
-		return start + "\\psbezier[linewidth=" + (thickness/ppc) + add + showPointsCode +  //$NON-NLS-1$
+		return start + "\\psbezier[linewidth=" + LaTeXDrawNumber.getCutNumber(thickness/ppc, threshold) + add + showPointsCode +  //$NON-NLS-1$
 				arrowParams + "]" + arrowsCode + coord; //$NON-NLS-1$
 	}
 	
