@@ -17,6 +17,7 @@ import latexDraw.ui.components.Delimitor;
 import latexDraw.ui.components.LaTeXDrawComboBox;
 import latexDraw.ui.components.LabelListCellRenderer;
 import latexDraw.ui.components.MagneticGrid;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 import latexDraw.util.LaTeXDrawResources;
 
@@ -670,6 +671,7 @@ public class Dot extends Figure
 	@Override
 	public String getCodePSTricks(DrawBorders drawBorders, float ppc)
 	{
+		double threshold = 0.001;
 		LaTeXDrawPoint2D o = drawBorders.getOriginPoint();
 		double x = center.x - o.x, y = o.y - center.y;
 		String start = "", end = "", add = ""; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
@@ -708,7 +710,7 @@ public class Dot extends Figure
 			
 			if(tmpX!=0f && tmpY!=0f)
 			{
-				start = "\\rput("+tmpX/ppc+", "+ tmpY/ppc +"){";  //$NON-NLS-1$//$NON-NLS-2$ //$NON-NLS-3$
+				start = "\\rput("+LaTeXDrawNumber.getCutNumber(tmpX/ppc,threshold)+", "+ LaTeXDrawNumber.getCutNumber(tmpY/ppc,threshold) +"){";  //$NON-NLS-1$//$NON-NLS-2$ //$NON-NLS-3$
 				end = "}"; //$NON-NLS-1$
 			}
 		}
@@ -716,8 +718,8 @@ public class Dot extends Figure
 		if(!currentStyle.equals(PSTricksConstants.DOT_STYLE))
 			add +=",dotstyle="+currentStyle; //$NON-NLS-1$
 		
-		return start + "\\psdots[dotsize=" +  (width/ppc) + add  //$NON-NLS-1$
-				+ "](" + (float)(x/ppc) + ',' + (float)(y/ppc) + ')' + end;//$NON-NLS-1$
+		return start + "\\psdots[dotsize=" +  LaTeXDrawNumber.getCutNumber(width/ppc,threshold) + add  //$NON-NLS-1$
+				+ "](" + LaTeXDrawNumber.getCutNumber((float)(x/ppc),threshold) + ',' + LaTeXDrawNumber.getCutNumber((float)(y/ppc),threshold) + ')' + end;//$NON-NLS-1$
 	}
 
 	
