@@ -14,6 +14,7 @@ import latexDraw.ui.LaTeXDrawFrame;
 import latexDraw.ui.components.Delimitor;
 import latexDraw.ui.components.MagneticGrid;
 import latexDraw.util.LaTeXDrawException;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 
 /** 
@@ -677,6 +678,7 @@ public class LaTeXDrawPolygon extends Figure implements DoubleBoundaryable
 		String coord="", add="", fillType=""; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 		int i, size = getNbPoints();
 		boolean isFilledWasChanged = false;
+		double threshold = 0.001;
 		
 		if(size<2) return null;
 		
@@ -686,8 +688,8 @@ public class LaTeXDrawPolygon extends Figure implements DoubleBoundaryable
 		for(i=0; i<size; i++)
 		{
 			p = getPoint(i);
-			coord+="("+(float)((p.x-d.x)/ppc)+","+ //$NON-NLS-1$//$NON-NLS-2$
-					(float)((d.y-p.y)/ppc)+")"; //$NON-NLS-1$
+			coord+="("+LaTeXDrawNumber.getCutNumber((float)((p.x-d.x)/ppc),threshold)+","+ //$NON-NLS-1$//$NON-NLS-2$
+					LaTeXDrawNumber.getCutNumber((float)((d.y-p.y)/ppc),threshold)+")"; //$NON-NLS-1$
 		}
 
 		if(hasShadow)
@@ -697,7 +699,7 @@ public class LaTeXDrawPolygon extends Figure implements DoubleBoundaryable
 				fillType+=",shadowangle="+(float)Math.toDegrees(shadowAngle);//$NON-NLS-1$
 			
 			if(((float)shadowSize)!=((float)DEFAULT_SHADOW_SIZE))
-				fillType+=",shadowsize="+(float)(shadowSize/PPC);//$NON-NLS-1$
+				fillType+=",shadowsize="+LaTeXDrawNumber.getCutNumber((float)(shadowSize/PPC),threshold);//$NON-NLS-1$
 			
 			if(!shadowColor.equals(PSTricksConstants.DEFAULT_SHADOW_COLOR))
 			{
@@ -724,7 +726,7 @@ public class LaTeXDrawPolygon extends Figure implements DoubleBoundaryable
 		
 		if(hasDoubleBoundary)
 		{
-			add+=",doubleline=true,doublesep="+(float)(doubleSep/ppc); //$NON-NLS-1$
+			add+=",doubleline=true,doublesep="+LaTeXDrawNumber.getCutNumber((float)(doubleSep/ppc),threshold); //$NON-NLS-1$
 			
 			if(doubleColor!=PSTricksConstants.DEFAULT_DOUBLE_COLOR)
 			{
@@ -740,7 +742,7 @@ public class LaTeXDrawPolygon extends Figure implements DoubleBoundaryable
 		
 		if(isFilledWasChanged) isFilled = false;
 		
-		return "\\pspolygon[linewidth=" + (thickness/ppc)  //$NON-NLS-1$
+		return "\\pspolygon[linewidth=" + LaTeXDrawNumber.getCutNumber(thickness/ppc,threshold)  //$NON-NLS-1$
 		+ add + fillType + "]"+coord; //$NON-NLS-1$
 	}
 
