@@ -1028,18 +1028,19 @@ public class LaTeXDrawRectangle extends LaTeXDrawPolygon implements BordersMovab
 			}
 		}
 
-		x2 = LaTeXDrawNumber.getCutNumber(x2, threshold);
-		y2 = LaTeXDrawNumber.getCutNumber(y2, threshold);
-		x1 = LaTeXDrawNumber.getCutNumber(x1, threshold);
-		y1 = LaTeXDrawNumber.getCutNumber(y1, threshold);
-
+		x2 = LaTeXDrawNumber.getCutNumber(x2/ppc, threshold);
+		y2 = LaTeXDrawNumber.getCutNumber(y2/ppc, threshold);
+		x1 = LaTeXDrawNumber.getCutNumber(x1/ppc, threshold);
+		y1 = LaTeXDrawNumber.getCutNumber(y1/ppc, threshold);
+		float th = LaTeXDrawNumber.getCutNumber(thickness/ppc, threshold); 
+		
 		if(isFilledWasChanged) isFilled = false;
 		
 		return addBegin
-				+ "\\psframe[linewidth=" + (thickness / ppc) + //$NON-NLS-1$
-				add + fillType+"](" + (float)(x2 / ppc) + ',' + //$NON-NLS-1$
-				(float)(y1 / ppc) + ")(" //$NON-NLS-1$
-				+ (float)(x1 / ppc) + ',' + (float)(y2 / ppc) + ')' + addEnd;
+				+ "\\psframe[linewidth=" + th + //$NON-NLS-1$
+				add + fillType+"](" + (float)x2 + ',' + //$NON-NLS-1$
+				(float)y1 + ")(" //$NON-NLS-1$
+				+ (float)x1 + ',' + (float)y2 + ')' + addEnd;
 	}
 
 
