@@ -728,8 +728,7 @@ public class Line extends LaTeXDrawPolygon implements Arrowable
 		LaTeXDrawPoint2D d = drawBorders.getOriginPoint();
 		LaTeXDrawPoint2D pt1 = getPoint(0);
 		LaTeXDrawPoint2D pt2 = getPoint(1);
-		double x1 = pt1.x - d.x, x2 = pt2.x - d.x, y1 = d.y - pt1.y, 
-			y2 = d.y - pt2.y;
+		double x1 = pt1.x - d.x, x2 = pt2.x - d.x, y1 = d.y - pt1.y, y2 = d.y - pt2.y;
 		String add ="", arrowsCode=""; //$NON-NLS-1$ //$NON-NLS-2$
 		double threshold = 0.001;
 		
@@ -751,7 +750,7 @@ public class Line extends LaTeXDrawPolygon implements Arrowable
 				add+=",shadowangle="+(float)Math.toDegrees(shadowAngle);//$NON-NLS-1$
 			
 			if(((float)shadowSize)!=((float)DEFAULT_SHADOW_SIZE))
-				add+=",shadowsize="+(float)(shadowSize/PPC);//$NON-NLS-1$
+				add+=",shadowsize="+LaTeXDrawNumber.getCutNumber((float)(shadowSize/PPC), threshold);//$NON-NLS-1$
 			
 			if(!shadowColor.equals(PSTricksConstants.DEFAULT_SHADOW_COLOR))
 			{
@@ -778,12 +777,12 @@ public class Line extends LaTeXDrawPolygon implements Arrowable
 		
 		if(lineStyle.equals(PSTricksConstants.LINE_DOTTED_STYLE))
 			add += ",linestyle="+lineStyle+",dotsep="+ //$NON-NLS-1$ //$NON-NLS-2$
-			(dotSep/ppc)+ "cm";	 //$NON-NLS-1$
+			LaTeXDrawNumber.getCutNumber(dotSep/ppc, threshold)+ "cm";	 //$NON-NLS-1$
 		else
 		if(lineStyle.equals(PSTricksConstants.LINE_DASHED_STYLE))
 			add += ",linestyle="+lineStyle+",dash=" +  //$NON-NLS-1$ //$NON-NLS-2$
-			(blackDashLength/ppc) + "cm "+  //$NON-NLS-1$
-			(whiteDashLength/ppc) + "cm"; //$NON-NLS-1$
+			LaTeXDrawNumber.getCutNumber(blackDashLength/ppc, threshold) + "cm "+  //$NON-NLS-1$
+			LaTeXDrawNumber.getCutNumber(whiteDashLength/ppc, threshold) + "cm"; //$NON-NLS-1$
 		
 		String currentArrowLStyle = arrowHeadL.getArrowStyle();
 		String currentArrowRStyle = arrowHeadR.getArrowStyle();		
@@ -826,7 +825,7 @@ public class Line extends LaTeXDrawPolygon implements Arrowable
 		
 		if(hasDoubleBoundary)
 		{
-			add+=",doubleline=true,doublesep="+(float)(doubleSep/ppc); //$NON-NLS-1$
+			add+=",doubleline=true,doublesep="+LaTeXDrawNumber.getCutNumber((float)(doubleSep/ppc), threshold); //$NON-NLS-1$
 			
 			if(doubleColor!=PSTricksConstants.DEFAULT_DOUBLE_COLOR)
 			{
@@ -840,7 +839,7 @@ public class Line extends LaTeXDrawPolygon implements Arrowable
 			}
 		}
 		
-		return "\\psline[linewidth=" + (thickness/ppc)+"cm"   //$NON-NLS-1$ //$NON-NLS-2$
+		return "\\psline[linewidth=" + LaTeXDrawNumber.getCutNumber(thickness/ppc, threshold)+"cm"   //$NON-NLS-1$ //$NON-NLS-2$
 			+ add + "]"+ arrowsCode + "(" + LaTeXDrawNumber.getCutNumber((float)(x1/ppc), threshold) + ","  //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 			+ LaTeXDrawNumber.getCutNumber((float)(y1/ppc), threshold)  + ")(" //$NON-NLS-1$
 			+ LaTeXDrawNumber.getCutNumber((float)(x2/ppc), threshold) + ","  //$NON-NLS-1$
