@@ -12,6 +12,7 @@ import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.ui.LaTeXDrawFrame;
 import latexDraw.ui.components.Delimitor;
 import latexDraw.ui.components.MagneticGrid;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 
 
@@ -621,6 +622,7 @@ public class Square extends LaTeXDrawRectangle
 		boolean isFilledWasChanged = false;
 		double x, y;
 		String add="", addBegin="", addEnd="", fillType=""; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
+		double threshold = 0.001;
 		
 		y = pt1.y>pt2.y ? pt1.y - width : pt1.y;
 		x = pt1.x>pt2.x ? pt1.x - width : pt1.x;
@@ -634,7 +636,7 @@ public class Square extends LaTeXDrawRectangle
 				fillType+=",shadowangle="+(float)Math.toDegrees(shadowAngle);//$NON-NLS-1$
 			
 			if(((float)shadowSize)!=((float)DEFAULT_SHADOW_SIZE))
-				fillType+=",shadowsize="+(float)(shadowSize/PPC);//$NON-NLS-1$
+				fillType+=",shadowsize="+LaTeXDrawNumber.getCutNumber((float)(shadowSize/PPC),threshold);//$NON-NLS-1$
 			
 			if(!shadowColor.equals(PSTricksConstants.DEFAULT_SHADOW_COLOR))
 			{
@@ -683,7 +685,7 @@ public class Square extends LaTeXDrawRectangle
 		
 		if(hasDoubleBoundary)
 		{
-			add+=",doubleline=true,doublesep="+(float)(doubleSep/ppc); //$NON-NLS-1$
+			add+=",doubleline=true,doublesep="+LaTeXDrawNumber.getCutNumber((float)(doubleSep/ppc),threshold); //$NON-NLS-1$
 			
 			if(doubleColor!=PSTricksConstants.DEFAULT_DOUBLE_COLOR)
 			{
@@ -697,15 +699,12 @@ public class Square extends LaTeXDrawRectangle
 			}
 		}
 		
-		if(Math.abs(x) < 0.001) x = 0;
-		if(Math.abs(y) < 0.001) y = 0;
-		
 		if(isFilledWasChanged) isFilled = false;
 		
-		return addBegin+"\\psframe[linewidth=" + (thickness/ppc) +  //$NON-NLS-1$
-				add + fillType+"](" + (float)((x+width)/ppc) + ',' +  //$NON-NLS-1$
-				(float)(y/ppc) + ")("  //$NON-NLS-1$
-				+ (float)(x/ppc) + ',' + (float)((y-width)/ppc) + ')'+addEnd;
+		return addBegin+"\\psframe[linewidth=" + LaTeXDrawNumber.getCutNumber(thickness/ppc,threshold) +  //$NON-NLS-1$
+				add + fillType+"](" + LaTeXDrawNumber.getCutNumber((float)((x+width)/ppc),threshold) + ',' +  //$NON-NLS-1$
+				LaTeXDrawNumber.getCutNumber((float)(y/ppc),threshold) + ")("  //$NON-NLS-1$
+				+ LaTeXDrawNumber.getCutNumber((float)(x/ppc),threshold) + ',' + LaTeXDrawNumber.getCutNumber((float)((y-width)/ppc),threshold) + ')'+addEnd;
 	}
 
 	
