@@ -173,7 +173,7 @@ public final class InstallerUI extends JFrame implements Runnable
 			plus = "";//$NON-NLS-1$
 		
 		panel1.add(new JLabel("<html><br><br><br><ul><li>"+"This installer will, create the necessary directories, place the templates in your profile<br>and place the latexdraw files in the chosen directory."+//$NON-NLS-1$
-				"</li><br><li>"+"You must be administrator/root to install LaTeXDraw."+ plus+"</li></ul></html>"), BorderLayout.CENTER);//$NON-NLS-1$//$NON-NLS-3$
+				"</li><br><li>"+"You may need to be administrator/root to install LaTeXDraw."+ plus+"</li></ul></html>"), BorderLayout.CENTER);//$NON-NLS-1$//$NON-NLS-3$
 		
 		setPanelDimension(panel1);
 	}
