@@ -139,7 +139,8 @@ public abstract class SVGElement implements Element, Cloneable
 		if(v!=null)
 		{
 			stylesCSS = new CSSStyleList();
-			new CSSStyleParser(v, stylesCSS).parseCSSStyles();
+			try { new CSSStyleParser(v, stylesCSS).parse(); }
+			catch(ParseException e) {e.printStackTrace(); }
 		}
 		
 		if(!checkAttributes())
@@ -616,7 +617,7 @@ public abstract class SVGElement implements Element, Cloneable
 	public String getUsablePrefix()
 	{ 
 		if(getNodeName()==null)
-			return null;
+			return "";
 		
 		int index = getNodeName().indexOf(':');
 		
@@ -1033,6 +1034,47 @@ public abstract class SVGElement implements Element, Cloneable
 	}
 	
 	
+	/**
+	 * @return The font-size value in point of the element, or from one of its parents.
+	 */
+	public float getFontSize() {
+		String fs = getAttribute(getUsablePrefix()+SVGAttributes.SVG_FONT_SIZE);
+		
+		return fs==null ? parent==null ? SVGLengthParser.FontSize.MEDIUM.getPointValue() : 
+					parent.getFontSize() : SVGLengthParser.fontSizetoPoint(fs);
+	}
+	
+	
+	/**
+	 * @return The defined or inherited font family. Otherwise, an empty string.
+	 */
+	public String getFontFamily() {
+		String fam = getAttribute(getUsablePrefix()+SVGAttributes.SVG_FONT_FAMILY);
+		
+		return fam==null ? parent==null ? "" : parent.getFontFamily() : fam;
+	}
+	
+	
+	/**
+	 * @return The defined or inherited font style. Otherwise, the default value "normal" is returned.
+	 */
+	public String getFontStyle() {
+		String style = getAttribute(getUsablePrefix()+SVGAttributes.SVG_FONT_STYLE);
+		
+		return style==null ? parent==null ? SVGAttributes.SVG_FONT_STYLE_NORMAL : parent.getFontStyle() : style;
+	}
+	
+	
+	/**
+	 * @return The defined or inherited font weight. Otherwise, the default value "normal" is returned.
+	 */
+	public String getFontWeight() {
+		String weight = getAttribute(getUsablePrefix()+SVGAttributes.SVG_FONT_WEIGHT);
+		
+		return weight==null ? parent==null ? SVGAttributes.SVG_FONT_WEIGHT_NORMAL : parent.getFontWeight() : weight;
+	}
+	
+	
 	
 	/**
 	 * Sets The colour of the stroke.
