@@ -14,6 +14,9 @@ import java.io.File;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.ObjectInputStream;
+import java.io.OutputStreamWriter;
+import java.util.Arrays;
+import java.util.Hashtable;
 import java.util.Locale;
 import java.util.Vector;
 
@@ -31,6 +34,9 @@ import javax.swing.SwingConstants;
 
 import latexDraw.figures.*;
 import latexDraw.figures.properties.Arrowable;
+import latexDraw.filters.PDFFilter;
+import latexDraw.filters.PSFilter;
+import latexDraw.filters.TeXFilter;
 import latexDraw.parsers.svg.SVGAttributes;
 import latexDraw.parsers.svg.SVGDocument;
 import latexDraw.parsers.svg.SVGElements;
@@ -39,10 +45,7 @@ import latexDraw.psTricks.DviPsColors;
 import latexDraw.ui.components.MagneticGrid;
 import latexDraw.ui.components.XScale;
 import latexDraw.ui.dialog.ExceptionFrameDialog;
-import latexDraw.util.LaTeXDrawException;
-import latexDraw.util.LaTeXDrawNamespace;
-import latexDraw.util.LaTeXDrawPoint2D;
-import latexDraw.util.UndoRedoManager;
+import latexDraw.util.*;
 import net.sourceforge.jiu.codecs.CodecMode;
 import net.sourceforge.jiu.codecs.PNMCodec;
 import net.sourceforge.jiu.gui.awt.BufferedRGB24Image;
@@ -171,6 +174,8 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 	protected MagneticGrid grid;
 	
 	
+	
+	
 	/**
 	 * The constructor by default.
 	 */
@@ -974,6 +979,231 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 	
 	
 	
+	public String getLatexDocument()
+	{
+		String packages		= getParentPanel().getCodePanel().getDocumentPackages();
+		String eol 			= System.getProperty("line.separator");//$NON-NLS-1$
+		StringBuffer doc 	= new StringBuffer();
+		parentPanel.updateCode();
+		String code 		= parentPanel.getCodePanel().getEditor().getCode(false, false);
+		LaTeXDrawPoint2D se = bordersComplete.getTheSEPoint();
+
+		if(packages==null)
+			packages = "";
+		
+		doc.append("\\documentclass{article}").append(eol).append("\\pagestyle{empty}").append(eol).append(packages).append(eol).append(
+			"\\usepackage[left=0cm,top=0.1cm,right=0cm,nohead,nofoot,paperwidth=").append(
+			se.x/pixelsPerCm).append("cm,paperheight=").append(
+			se.y/pixelsPerCm+0.3).append("cm]{geometry}").append(
+			eol).append("\\usepackage[usenames,dvipsnames]{pstricks}").append(//$NON-NLS-1$//$NON-NLS-2$
+			eol).append("\\usepackage{pstricks-add}").append(eol).append("\\usepackage{epsfig}").append(//$NON-NLS-1$//$NON-NLS-2$
+			eol).append("\\usepackage{pst-grad}").append(eol).append("\\usepackage{pst-plot}").append(eol).append(//$NON-NLS-1$//$NON-NLS-2$
+			 "\\begin{document}").append(eol).append(
+			"\\addtolength{\\oddsidemargin}{-0.2in}").append(eol).append("\\addtolength{\\evensidemargin}{-0.2in}").append(
+			eol).append(code).append(eol).append("\\end{document}");//$NON-NLS-1$//$NON-NLS-2$
+
+		return doc.toString();
+	}
+	
+	
+	
+	public File createLatexFile(String pathExportTex)
+	{
+		if(pathExportTex==null)
+			return null;
+		
+		try {
+			String doc 				= getLatexDocument();
+			FileOutputStream fos   	= new FileOutputStream(pathExportTex);
+			OutputStreamWriter osw 	= new OutputStreamWriter(fos);
+			
+			osw.append(doc);
+			osw.flush();
+			osw.close();
+			fos.flush();
+			fos.close();
+			
+			return new File(pathExportTex);
+		}
+		catch(Exception e) { return null; }
+	}
+	
+	
+	private void showErrorDialogLatexCompilation(String log) {
+		String text = log==null || log.length()==0 ? "Check the path of your latex distribution in your preferences." : log;
+		ExceptionFrameDialog dialog = new ExceptionFrameDialog(new IllegalAccessException(text));
+		
+		dialog.setTitle("Document not created");
+		dialog.setInfoLabel("The document cannot be created.");
+		dialog.getEditor().setText(text);
+		dialog.getEditor().setCaretPosition(0);
+		dialog.setVisible(true);
+	}
+	
+	
+	
+	/**
+	 * Create a .ps file that corresponds to the compiled latex document containing
+	 * the pstricks drawing.
+	 * @param latexDistribPath The path locating latex.
+	 * @param pathExportPs The path of the .ps file to create (MUST ends with .ps).
+	 * @param tmpDir The temporary folder that will be used to contain temp files.
+	 * If null, a new temp folder is created.
+	 * @return The create file or null.
+	 * @throws IllegalArgumentException If a problem occurs.
+	 * @since 2.1
+	 */
+	private File createPSFile(String latexDistribPath, String pathExportPs, File tmpDir) {
+		if(latexDistribPath==null || pathExportPs==null)
+			return null;
+		
+		String dirBin   = parentPanel.getFrameParent().getPathDistribLatex();
+		String sep		= System.getProperty("file.separator");	//$NON-NLS-1$
+		int lastSep		= pathExportPs.lastIndexOf(sep)+1;
+		String name		= pathExportPs.substring(lastSep==-1 ? 0 : lastSep, pathExportPs.lastIndexOf(PSFilter.PS_EXTENSION));
+		File tmpDir2	= tmpDir==null ? createTempDir() : tmpDir;
+		
+		if(tmpDir2==null) {
+			System.err.println("Cannot create a temporary folder.");
+			return null;
+		}
+		
+		File texFile    = createLatexFile(name + TeXFilter.TEX_EXTENSION);
+		String log;
+		File finalPS;
+		LaTeXDrawPoint2D nw = bordersComplete.getTheNWPoint(), se = bordersComplete.getTheSEPoint();
+		float dec		= 0.2f;
+		String path		= tmpDir2.getAbsolutePath() + sep;
+		
+		if(texFile==null || !texFile.exists())
+			return null;
+
+		String[] paramsLatex = new String[] {dirBin+"latex", "--interaction=nonstopmode", "--output-directory=" + tmpDir2,//$NON-NLS-1$//$NON-NLS-2$//$NON-NLS-3$
+											texFile.getAbsolutePath()};
+		log    = execute(paramsLatex, tmpDir2);
+		File dviFile = new File(tmpDir2.getAbsolutePath() + sep + name + ".dvi");
+		boolean dviRenamed = dviFile.renameTo(new File(tmpDir2.getAbsolutePath() + sep + name));
+		String[] paramsDvi = new String[] {dirBin+"dvips", "-T", ((se.x-nw.x)/pixelsPerCm+dec)+"cm,"+((se.y-nw.y)/pixelsPerCm+dec)+"cm",
+											name, "-o", pathExportPs};
+		dirBin = dirBin==null ? "" : dirBin.endsWith(sep) || dirBin.length()==0 ? dirBin : dirBin + sep;
+		log   += execute(paramsDvi, tmpDir2);
+		
+		texFile.delete();
+		new File(path + name + (dviRenamed ? "" : ".div")).delete();	//$NON-NLS-1$
+		new File(path + name + ".log").delete();						//$NON-NLS-1$
+		new File(path + name + ".aux").delete();						//$NON-NLS-1$
+		
+		finalPS = new File(pathExportPs);
+		
+		if(!finalPS.exists()) {
+			showErrorDialogLatexCompilation(log);
+			finalPS = null;
+		}
+		
+		if(tmpDir==null)
+			tmpDir2.delete();
+		
+		return finalPS;
+	}
+	
+	
+	/**
+	 * Create a .ps file that corresponds to the compiled latex document containing
+	 * the pstricks drawing.
+	 * @param latexDistribPath The path locating latex.
+	 * @param pathExportPs The path of the .ps file to create (MUST ends with .ps).
+	 * @return The create file or null.
+	 * @throws IllegalArgumentException If a problem occurs.
+	 * @since 2.1
+	 */
+	public File createPSFile(String latexDistribPath, String pathExportPs){
+		return createPSFile(latexDistribPath, pathExportPs, null);
+	}
+	
+	
+	
+	/**
+	 * Creates a temporary directory that will be used to contains temporary latex files.
+	 * The created folder will have restricted access: only the user can access the folder.
+	 * @return The created folder or null.
+	 */
+	private File createTempDir() {
+		String pathTmp  = System.getProperty("java.io.tmpdir");	//$NON-NLS-1$
+		String sep		= System.getProperty("file.separator");	//$NON-NLS-1$
+		String path		= pathTmp + (pathTmp.endsWith(sep) ? "" : sep) + "latexdrawTmp" + System.currentTimeMillis();
+		File tmpDir		= new File(path);
+		boolean ok		= tmpDir.mkdir();
+		
+
+		tmpDir.setReadable(false, false);// Rights are removed for everybody.
+		tmpDir.setReadable(true, true); // They are added to the owner only.
+		tmpDir.setWritable(false, false);// same thing here.
+		tmpDir.setWritable(true, true);
+		
+		return ok ? tmpDir : null;
+	}
+	
+	
+	
+	/**
+	 * Create a .pdf file that corresponds to the compiled latex document containing
+	 * the pstricks drawing.
+	 * @param latexDistribPath The path locating latex.
+	 * @param pathExportPdf The path of the .pdf file to create (MUST ends with .pdf).
+	 * @return The create file or null.
+	 * @param crop if true, the output document will be cropped.
+	 * @throws IllegalArgumentException If a problem occurs.
+	 * @since 2.1
+	 */
+	public File createPDFFile(String latexDistribPath, String pathExportPdf, boolean crop) {
+		if(pathExportPdf==null || latexDistribPath==null)
+			return null;
+		
+		String dirBin   = parentPanel.getFrameParent().getPathDistribLatex();
+		String sep		= System.getProperty("file.separator");	//$NON-NLS-1$
+		String name		= pathExportPdf.substring(pathExportPdf.lastIndexOf(sep)+1, pathExportPdf.lastIndexOf(PDFFilter.PDF_EXTENSION));
+		File tmpDir		= createTempDir();
+		
+		if(tmpDir==null) {
+			System.err.println("Cannot create a temporary folder.");
+			return null;
+		}
+		
+		File psFile = createPSFile(latexDistribPath, tmpDir.getAbsolutePath() + sep + name + PSFilter.PS_EXTENSION, tmpDir);
+		String log;
+		File pdfFile;
+		
+		if(psFile==null)
+			return null;
+
+		dirBin  = dirBin==null ? "" : dirBin.endsWith(sep) || dirBin.length()==0 ? dirBin : dirBin + sep;
+		log 	= execute(new String[] {dirBin + "ps2pdf", psFile.getAbsolutePath(), 
+							crop ? name + PDFFilter.PDF_EXTENSION : pathExportPdf}, tmpDir);
+		
+		if(crop) {
+			pdfFile = new File(latexDistribPath, tmpDir.getAbsolutePath() + sep + name + PDFFilter.PDF_EXTENSION);
+			log 	= execute(new String[] {dirBin + "pdfcrop", pdfFile.getAbsolutePath(), pdfFile.getAbsolutePath()}, tmpDir);
+			if(!pdfFile.renameTo(new File(pathExportPdf)))// JAVA7: test pdfFile.toPath().move(pathExportPdf)
+				if(!LFileUtils.copy(pdfFile, new File(pathExportPdf)))// the renameto method is weak and fails sometimes.
+					log += " The final pdf document cannot be moved to its final destination.";
+			pdfFile.delete();
+		}
+		
+		pdfFile = new File(pathExportPdf);
+		psFile.delete();
+		
+		if(!pdfFile.exists() || log.length()>0) {
+			showErrorDialogLatexCompilation(log);
+			pdfFile = null;
+		}
+		
+		tmpDir.delete();
+				
+		return pdfFile;
+	}
+	
+	
+	
 	/**
 	 * Allows to export the drawing as a eps file
 	 * @param file The new eps file
@@ -1466,8 +1696,6 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 	{
 	   	if(g==null || figures==null) return;
 
-    	g.setColor(Color.WHITE);
-    	g.fillRect(0, 0, getWidth(), getHeight());
 		Graphics2D g2 = (Graphics2D) g;
 		g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, antiAliasingValue);
 		g2.setRenderingHint(RenderingHints.KEY_RENDERING, renderingValue);
@@ -1517,6 +1745,10 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 	public void paintComponent(Graphics g)
     {   	
     	super.paintComponents(g);
+    	
+    	g.setColor(Color.WHITE);
+    	g.fillRect(0, 0, getWidth(), getHeight());
+    	
     	paintFigures(g, true, true);
     		
     	try
@@ -2051,23 +2283,23 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 				if(size<2)
 					return ;
 				
+				Figure f;
 				int[] id = new int[size];
-				Draw d = (Draw)selected.clone();
+				Draw d   = new Draw(true, true);
+				Hashtable<Integer, Figure> table = new Hashtable<Integer, Figure>();
 				
-				for(i=0; i<size; i++)
-				{
+				for(i=0; i<size; i++) {
 					id[i] = figures.indexOf(selected.getFigureAt(i));
-					figures.remove(id[i]);
+					table.put(id[i], figures.elementAt(id[i]));
 				}
 				
+				Arrays.sort(id);
 				min = id[0];
-				i = 1;
 				
-				while(i<size)
-				{
-					if(id[i]<min)
-						min = id[i];
-					i++;
+				for(i=0; i<id.length; i++) {
+					f = table.get(id[i]);
+					d.addFigure(f);
+					figures.remove(f);
 				}
 				
 				if(undoManager!=null)
@@ -2949,8 +3181,6 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 						setWhichCodeOutput(Double.valueOf(n.getTextContent()).shortValue());
 					else if(name.endsWith(LaTeXDrawNamespace.XML_DISPLAY_GRID))
 						displayGrid = Boolean.valueOf(n.getTextContent()).booleanValue();
-					else if(name.endsWith(LaTeXDrawNamespace.XML_DRAW_BORDERS))
-						setDrawBorders(Boolean.valueOf(n.getTextContent()).booleanValue());
 				}
 				catch(Exception e) { System.out.println(name + ": invalid value."); } //$NON-NLS-1$
 			}
@@ -3016,4 +3246,26 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 	{
 		this.drawBorders = drawBorders;
 	}
+	
+	
+	
+	private static String execute(String[] cmd, File dir) {
+		if(cmd==null || cmd.length==0)
+			return null;
+		
+		try {
+			Runtime runtime = Runtime.getRuntime();
+			Process process = runtime.exec(cmd, null, dir);// Command launched
+			
+			StreamExecReader err = new StreamExecReader(process.getErrorStream());// Catch the error log
+			StreamExecReader inp = new StreamExecReader(process.getInputStream());// Catch the log
+			
+			err.start();
+			inp.start();
+			
+			process.waitFor();// Waiting for the end of the process.
+			
+			return err.getLog();
+		} catch(Exception e) { return ""; }
+	}
 }
