@@ -638,7 +638,7 @@ public class BatchConvertFrame extends JFrame implements ActionListener, ListSel
 				return null;
 			
 			Image image=null;
-			URL url = f.toURL();
+			URL url = f.toURI().toURL();
 			URLConnection connection = url.openConnection();
 		    String type = connection.getContentType();
 		
