@@ -17,10 +17,7 @@ import latexDraw.ui.LaTeXDrawFrame;
 import latexDraw.ui.components.Delimitor;
 import latexDraw.ui.components.MagneticGrid;
 import latexDraw.ui.components.XScale;
-import latexDraw.util.LaTeXDrawException;
-import latexDraw.util.LaTeXDrawNamespace;
-import latexDraw.util.LaTeXDrawPath;
-import latexDraw.util.LaTeXDrawResources;
+import latexDraw.util.*;
 
 import org.w3c.dom.*;
 
@@ -107,6 +104,8 @@ public class PreferencesFrame extends JFrame implements ActionListener
 
 	public static final String NAME_BUTTON_TEX_EDITOR = "BUTTON_TEX_EDITOR";//$NON-NLS-1$
 
+	public static final String NAME_BUTTON_LATEX_DISTRIB = "BUTTON_LATEX";//$NON-NLS-1$
+
 	/** The label of the check-box code auto-update */
 	public static final String LABEL_AUTOUPDATE = LaTeXDrawLang.getDialogFrameString("PreferencesFrame.codeAuto"); //$NON-NLS-1$
 	
@@ -166,6 +165,10 @@ public class PreferencesFrame extends JFrame implements ActionListener
 
 	private JTextField pathTexEditorField;
 	
+	private JTextField pathLatexDistribField;
+	
+	private JTextArea latexIncludes;
+	
 	/** Allows to set the unit of length by default */
 	private JComboBox unitChoice;
 	
@@ -217,6 +220,8 @@ public class PreferencesFrame extends JFrame implements ActionListener
 	private boolean curColRender;
 	private boolean curRendering;
 	private boolean curAntiAlias;
+	private String curLatexDistrib;
+	private String curLatexIncludes;
 	
 
 	
@@ -249,6 +254,7 @@ public class PreferencesFrame extends JFrame implements ActionListener
 	  		tabbedPane.add(LaTeXDrawLang.getStringLaTeXDrawFrame("LaTeXDrawFrame.90"), createDisplayPanel()); //$NON-NLS-1$
 	  		tabbedPane.add(LaTeXDrawLang.getStringLaTeXDrawFrame("LaTeXDrawFrame.92"), createCodePanel()); //$NON-NLS-1$
 	  		tabbedPane.add(LaTeXDrawLang.getDialogFrameString("PreferencesFrame.grid"), createGridPanel()); //$NON-NLS-1$
+	  		tabbedPane.add("LaTeX", createLatexPanel()); //$NON-NLS-1$
 	  		
 	  		JButton buttonOk  = new JButton(AbstractParametersFrame.LABEL_OK), 
 				buttonCancel  = new JButton(AbstractParametersFrame.LABEL_CANCEL),
@@ -270,7 +276,7 @@ public class PreferencesFrame extends JFrame implements ActionListener
 			pGeneral.add(pButton, BorderLayout.SOUTH);
 	  		
 			getContentPane().add(pGeneral);
-	  		setSize(370, 310);//Fixes #1562954
+	  		setSize(480, 310);//Fixes #1562954
 			setVisible(false);
 			
 			readXMLPreferences();
@@ -315,11 +321,13 @@ public class PreferencesFrame extends JFrame implements ActionListener
   		pathTexEditorField.setMaximumSize(new Dimension(300,30));
   		checkNewVersion = new JCheckBox(LABEL_CHECK_VERSION);
   		langList = new JComboBox();
+  		langList.addItem(LaTeXDrawLang.LANG_DE);
   		langList.addItem(LaTeXDrawLang.LANG_EN);
   		langList.addItem(LaTeXDrawLang.LANG_EN_US);
-  		langList.addItem(LaTeXDrawLang.LANG_FR);
   		langList.addItem(LaTeXDrawLang.LANG_ES);
-  		langList.addItem(LaTeXDrawLang.LANG_DE);
+  		langList.addItem(LaTeXDrawLang.LANG_FR);
+  		langList.addItem(LaTeXDrawLang.LANG_IT);
+  		langList.addItem(LaTeXDrawLang.LANG_PL);
   		langList.setSelectedItem(LaTeXDrawLang.getlangCurrent());
   		langList.setPreferredSize(new Dimension(75, 30));
   		langList.setSize(new Dimension(75, 30));
@@ -420,6 +428,38 @@ public class PreferencesFrame extends JFrame implements ActionListener
 	
 	
 	
+	private JPanel createLatexPanel()
+	{
+		JPanel pLatex 		 = new JPanel();
+		JPanel pLatexDistrib = new JPanel();
+		JLabel label         =  new JLabel("The path of the latex binaires:");
+		
+		label.setAlignmentX(Component.RIGHT_ALIGNMENT);
+		pLatex.setLayout(new BoxLayout(pLatex, BoxLayout.Y_AXIS));
+		pLatexDistrib.setLayout(new BoxLayout(pLatexDistrib, BoxLayout.X_AXIS));
+  		pathLatexDistribField = new JTextField();
+  		pathLatexDistribField.setMaximumSize(new Dimension(700,30));
+  		pathLatexDistribField.setMinimumSize(new Dimension(300,30));
+  		
+  		JButton bChooseLatex  = new JButton(LaTeXDrawResources.openIcon);
+  		bChooseLatex.addActionListener(this);
+  		bChooseLatex.setActionCommand(NAME_BUTTON_LATEX_DISTRIB);
+  		
+  		latexIncludes = new JTextArea();
+  		latexIncludes.setToolTipText("<html>Include in this list the latex packages you regularly use in your drawing, e.g. :<br>\\usepackage[frenchb]{babel}<br>\\usepackage[utf8]{inputenc}</html>");
+  		JScrollPane scrollPane = new JScrollPane(latexIncludes); 
+  		
+  		pLatexDistrib.add(pathLatexDistribField);
+  		pLatexDistrib.add(bChooseLatex);
+  		pLatex.add(label);
+  		pLatex.add(pLatexDistrib);
+  		pLatex.add(scrollPane);
+  		
+		return pLatex;
+	}
+	
+	
+	
 	/**
 	 * Allows to create the panel which allows the user to set the preferences about displayable elements.
 	 * @return The panel.
@@ -599,6 +639,8 @@ public class PreferencesFrame extends JFrame implements ActionListener
 					checkNewVersion.setSelected(curCheckVers);
 					displayCodePanelCB.setSelected(curDisplayCode);
 					displayBordersCB.setSelected(curDisplayBord);
+					latexIncludes.setText(curLatexIncludes);
+					pathLatexDistribField.setText(curLatexDistrib);
 					
 					return;
 				}
@@ -612,6 +654,8 @@ public class PreferencesFrame extends JFrame implements ActionListener
 				if(label.equals(NAME_BUTTON_OK))
 				{
 					writeXMLPreferences(true);
+					mainFrame.setLatexIncludes(latexIncludes.getText());
+					mainFrame.setPathDistribLatex(pathLatexDistribField.getText());
 					mainFrame.setPathTexEditor(pathTexEditorField.getText());
 					mainFrame.setPathExport(pathExportField.getText());
 					mainFrame.setPathOpen(pathOpenField.getText());
@@ -635,6 +679,18 @@ public class PreferencesFrame extends JFrame implements ActionListener
 					return;
 				}
 				
+				if(label.equals(NAME_BUTTON_LATEX_DISTRIB))
+				{ 
+					fileChooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
+					fileChooser.showSaveDialog(this);
+					File file = fileChooser.getSelectedFile();
+					
+					if(file!=null && file.exists() && file.isFile())
+						pathLatexDistribField.setText(file.getPath());
+					
+					return;
+				}
+				
 				if(label.equals(NAME_BUTTON_OPENFIELD))
 				{ 
 					fileChooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
@@ -725,7 +781,9 @@ public class PreferencesFrame extends JFrame implements ActionListener
             	if(name==null || name.length()==0)
             		continue;
             	
-            	if(name.equals(LaTeXDrawNamespace.XML_ALPHA_INTER)) alpaInterCheckBox.setSelected(Boolean.valueOf(content).booleanValue());
+            	if(name.equals(LaTeXDrawNamespace.XML_LATEX_INCLUDES)) latexIncludes.setText(content);
+            	else if(name.equals(LaTeXDrawNamespace.XML_PATH_LATEX_DISTRIB)) pathLatexDistribField.setText(content);
+            	else if(name.equals(LaTeXDrawNamespace.XML_ALPHA_INTER)) alpaInterCheckBox.setSelected(Boolean.valueOf(content).booleanValue());
             	else if(name.equals(LaTeXDrawNamespace.XML_ANTI_ALIAS)) antialiasingCheckBox.setSelected(Boolean.valueOf(content).booleanValue());
             	else if(name.equals(LaTeXDrawNamespace.XML_AUTO_UPDATE)) codeAutoUpdateCB.setSelected(Boolean.valueOf(content).booleanValue());
             	else if(name.equals(LaTeXDrawNamespace.XML_CHECK_VERSION)) checkNewVersion.setSelected(Boolean.valueOf(content).booleanValue());
@@ -933,6 +991,14 @@ public class PreferencesFrame extends JFrame implements ActionListener
             elt.setTextContent(pathTexEditorField.getText());
             root.appendChild(elt);
             
+            elt = document.createElement(LaTeXDrawNamespace.XML_PATH_LATEX_DISTRIB);
+            elt.setTextContent(pathLatexDistribField.getText());
+            root.appendChild(elt);
+            
+            elt = document.createElement(LaTeXDrawNamespace.XML_LATEX_INCLUDES);
+            elt.setTextContent(latexIncludes.getText());
+            root.appendChild(elt);
+            
             elt = document.createElement(LaTeXDrawNamespace.XML_RECENT_FILES);
             elt.setAttribute(LaTeXDrawNamespace.XML_NB_RECENT_FILES, nbRecentFilesField.getValue().toString());
             root.appendChild(elt);
@@ -1200,15 +1266,18 @@ public class PreferencesFrame extends JFrame implements ActionListener
 			draw.setAlphaInterValue(alpaInterCheckBox.isSelected());
 			draw.setRenderingValue(renderingCheckBox.isSelected());
 			
+			mainFrame.setLatexIncludes(latexIncludes.getText());
+			mainFrame.setPathDistribLatex(pathLatexDistribField.getText());
 			mainFrame.setMagneticGrid(magneticGridCB.isSelected());
 			mainFrame.setPathExport(pathExportField.getText());
 			mainFrame.setPathOpen(pathOpenField.getText());
+			mainFrame.displayCodePanel(displayCodePanelCB.isSelected());
 			mainFrame.setFormerIsInAutoUpdate(codeAutoUpdateCB.isSelected());
-			mainFrame.getCodePanel().setIsInAutoUpdate(codeAutoUpdateCB.isSelected());
+			mainFrame.setIsInAutoUpdate(codeAutoUpdateCB.isSelected());
 			
 			if(LaTeXDrawFrame.WITH_UPDATE)
+				
 				mainFrame.setCheckNewVersion(checkNewVersion.isSelected());
-			mainFrame.displayCodePanel(displayCodePanelCB.isSelected());
 			mainFrame.displayGrid(displayGridCB.isSelected(), classicGridRB.isSelected());
 			mainFrame.setPersoGridGap(Integer.valueOf(persoGridGapField.getValue().toString()).intValue());
 			mainFrame.displayXScale(displayXScaleCB.isSelected());
@@ -1434,6 +1503,8 @@ public class PreferencesFrame extends JFrame implements ActionListener
 			curColRender	 = colorRenderCheckBox.isSelected();
 			curRendering	 = renderingCheckBox.isSelected();
 			curAntiAlias	 = antialiasingCheckBox.isSelected();
+			curLatexDistrib  = pathLatexDistribField.getText();
+			curLatexIncludes = latexIncludes.getText();
 		}
 		catch(Exception e) { e.printStackTrace(); }
 		
